/*******************************************

 PMACH.H - The KINT Interpreter
	Copyright 2002 Everett Kaser
	All rights reserved.

	Do not copy or redistribute without the
	author's explicit written permission.
 *******************************************/

//***************************
//* KINT version numbers
//***************************
#define	INTERP_MAJOR_REV	1
#define	INTERP_MINOR_REV	4

//*********************************************************************************
//* The following macros are used in PMACH.CPP and SYSFUNCS.CPP in order to make
//* it easier for porting this code to "big-endian" CPUs.  "All" you have to do
//* is rewrite these macros, and MOST of the little-to-big-endian conversion will
//* be done.  Although, NO DOUBT, I've used these macros in some places where
//* I shouldn't have, and haven't used them in some places where I should have.
//* BEWARE!
//*********************************************************************************
#define GETREGD(regoff)			(*((DWORD *)(Kregs + (regoff))))
#define	GETREGW(regoff)			(*(( WORD *)(Kregs + (regoff))))
#define GETREGB(regoff)			(*(( BYTE *)(Kregs + (regoff))))

#define	SETREGD(regoff, value)	(*((DWORD *)(Kregs + (regoff))) = (DWORD)(value))
#define	SETREGW(regoff, value)	(*(( WORD *)(Kregs + (regoff))) = ( WORD)(value))
#define SETREGB(regoff, value)	(*(( BYTE *)(Kregs + (regoff))) = ( BYTE)(value))

#define	GETMEMD(addr)			(*((DWORD *)(addr)))
#define	GETMEMW(addr)			(*(( WORD *)(addr)))
#define	GETMEMB(addr)			(*(( BYTE *)(addr)))

#define	SETMEMD(addr, value)	(*((DWORD *)(addr)) = (DWORD)(value))
#define	SETMEMW(addr, value)	(*(( WORD *)(addr)) = ( WORD)(value))
#define	SETMEMB(addr, value)	(*(( BYTE *)(addr)) = ( BYTE)(value))

//**********************************************
//* "cmd" (event) offsets into a .KE file header
//**********************************************
#define	KHDR_NULLPTR			0
#define	KHDR_MAJOR_INTERP_REV	6
#define	KHDR_MINOR_INTERP_REV	7
#define	KHDR_CODE_SIZE			8
#define	KHDR_ZERODATA_SIZE		12
#define	KHDR_STACK_SIZE			16
#define	KHDR_UNUSED1			20
#define	KHDR_UNUSED2			24
#define	KHDR_UNUSED3			28
#define	KHDR_UNUSED4			32
#define	KHDR_UNUSED5			36
#define	KHDR_UNUSED6			40
#define	KHDR_UNUSED7			44
#define	KHDR_UNUSED8			48
#define	KHDR_UNUSED9			52
#define	KHDR_UNUSED10			56
#define	KHDR_SCREEN_CHANGE		60
#define	KHDR_ALPHAKEY_DOWN		64
#define	KHDR_ALPHAKEY_UP		68
#define	KHDR_BEGIN_STARTUP		72
#define	KHDR_END_STARTUP		76
#define	KHDR_WINDOW_HIDDEN		80
#define	KHDR_WINDOW_MOVE		84
#define	KHDR_WINDOW_SIZE		88
#define	KHDR_POINTER_MOVE		92
#define	KHDR_KEY_DOWN			96
#define	KHDR_KEY_UP				100
#define	KHDR_CHAR				104
#define	KHDR_TIMER				108
#define	KHDR_IDLE				112
#define	KHDR_MUSIC_DONE			116
#define	KHDR_QUERY_QUIT			120
#define	KHDR_SHUT_DOWN			124

//*************************************
//* offsets in REGISTER BYTE array for
//* each numbered register.
//*************************************
#define	REG_0	0x00
#define	REG_1	0x04
#define	REG_2	0x08
#define	REG_3	0x0C
#define	REG_4	0x10
#define	REG_5	0x14
#define	REG_6	0x18
#define	REG_7	0x1C
#define	REG_8	0x20
#define	REG_9	0x24
#define	REG_10	0x28
#define	REG_11	0x2C
#define	REG_12	0x30
#define	REG_13	0x34
#define	REG_14	0x38
#define	REG_15	0x3C
#define	REG_16	0x40
#define	REG_17	0x44
#define	REG_18	0x48
#define	REG_19	0x4C
#define	REG_20	0x50
#define	REG_21	0x54
#define	REG_22	0x58
#define	REG_23	0x5C
#define	REG_24	0x60
#define	REG_25	0x64
#define	REG_26	0x68
#define	REG_27	0x6C
#define	REG_28	0x70
#define	REG_29	0x74
#define	REG_30	0x78
#define	REG_31	0x7C
#define	REG_32	0x80
#define	REG_33	0x82
#define	REG_34	0x84
#define	REG_35	0x86
#define	REG_36	0x88
#define	REG_37	0x8A
#define	REG_38	0x8C
#define	REG_39	0x8E
#define	REG_40	0x90
#define	REG_41	0x92
#define	REG_42	0x94
#define	REG_43	0x96
#define	REG_44	0x98
#define	REG_45	0x9A
#define	REG_46	0x9C
#define	REG_47	0x9E
#define	REG_48	0xA0
#define	REG_49	0xA2
#define	REG_50	0xA4
#define	REG_51	0xA6
#define	REG_52	0xA8
#define	REG_53	0xAA
#define	REG_54	0xAC
#define	REG_55	0xAE
#define	REG_56	0xB0
#define	REG_57	0xB2
#define	REG_58	0xB4
#define	REG_59	0xB6
#define	REG_60	0xB8
#define	REG_61	0xBA
#define	REG_62	0xBC
#define	REG_63	0xBE
#define	REG_64	0xC0
#define	REG_65	0xC2
#define	REG_66	0xC4
#define	REG_67	0xC6
#define	REG_68	0xC8
#define	REG_69	0xCA
#define	REG_70	0xCC
#define	REG_71	0xCE
#define	REG_72	0xD0
#define	REG_73	0xD2
#define	REG_74	0xD4
#define	REG_75	0xD6
#define	REG_76	0xD8
#define	REG_77	0xDA
#define	REG_78	0xDC
#define	REG_79	0xDE
#define	REG_80	0xE0
#define	REG_81	0xE1
#define	REG_82	0xE2
#define	REG_83	0xE3
#define	REG_84	0xE4
#define	REG_85	0xE5
#define	REG_86	0xE6
#define	REG_87	0xE7
#define	REG_88	0xE8
#define	REG_89	0xE9
#define	REG_90	0xEA
#define	REG_91	0xEB
#define	REG_92	0xEC
#define	REG_93	0xED
#define	REG_94	0xEE
#define	REG_95	0xEF
#define	REG_96	0xF0
#define	REG_97	0xF1
#define	REG_98	0xF2
#define	REG_99	0xF3
#define	REG_100	0xF4
#define	REG_101	0xF5
#define	REG_102	0xF6
#define	REG_103	0xF7
#define	REG_104	0xF8
#define	REG_105	0xF9
#define	REG_106	0xFA
#define	REG_107	0xFB
#define	REG_108	0xFC
#define	REG_109	0xFD
#define	REG_110	0xFE
#define	REG_111	0xFF

//*****************************
//* function prototypes
//*****************************
BOOL LoadKEFile(char *);
WORD KEevent(WORD cmd, DWORD arg1, DWORD arg2, DWORD arg3);
